Bug 2419

Summary: [Performance] Rootfs generation is inefficient (license checks)
Product: [Build System, Metadata & Runtime] Meta-yocto Reporter: Richard Purdie <richard.purdie>
Component: meta-yoctoAssignee: Beth Flanagan <elizabeth.flanagan>
Status: VERIFIED FIXED QA Contact:
Severity: normal    
Priority: Medium CC: elizabeth.flanagan, jiajun.xu, laurentiu.serban, poky.bs.watcher, poky.watcher, sgw, song.liu
Version: 1.3   
Target Milestone: 1.3 M1   
Hardware: x86   
OS: Multiple   
Whiteboard: (P1)(Covered by current QA test plan)(Merged)
OS type for building Yocto: --- Type of Regression: ---
Verified: Documentation change: ---

Description Richard Purdie 2012-05-04 13:27:50 UTC
The license checks made at do_rootfs time are a fork bomb and extremely inefficient. We should remove the overhead of an exec call of "find" so many times in particular and use shell expansion instead or similar.
Comment 1 Beth Flanagan 2012-05-11 19:16:13 UTC
This is going to be a rewrite of that function. I'm part way through it now.
Comment 2 Jiajun Xu 2012-05-21 08:12:59 UTC
The feature could be covered by current QA performance testing.
Comment 5 Laurentiu Serban 2012-06-20 08:53:05 UTC
The build time for core-image-sato improved to 95 minutes (previous was 110 minutes)
Comment 6 Beth Flanagan 2012-06-20 11:42:43 UTC
(In reply to comment #5)
> The build time for core-image-sato improved to 95 minutes (previous was 110
> minutes)

do we know what the do_rootfs time was?
Comment 7 Laurentiu Serban 2012-06-20 13:04:25 UTC
4 minutes 43 seconds for do_rootfs and do_build